@@ -42,11 +42,7 @@ public:
 
 FindSaneDevicesThread *FindSaneDevicesThread::getInstance()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QMutexLocker<QMutex> locker(s_mutexsane);
-#else
-    QMutexLocker locker(s_mutexsane);
-#endif
 
     if (s_instancesane == nullptr) {
         s_instancesane = new FindSaneDevicesThread();
@@ -61,11 +57,7 @@ FindSaneDevicesThread::FindSaneDevicesThread() : QThread(nullptr)
 
 FindSaneDevicesThread::~FindSaneDevicesThread()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QMutexLocker<QMutex> locker(s_mutexsane);
-#else
-    QMutexLocker locker(s_mutexsane);
-#endif
     qDeleteAll(m_deviceList);
     wait();
 }
